==> zio-aws-ec2_2.13-5.19.8.1-sources.jar: zio/aws/ec2/model/EnableReachabilityAnalyzerOrganizationSharingRequest.scala <==
package zio.aws.ec2.model
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class EnableReachabilityAnalyzerOrganizationSharingRequest() {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.EnableReachabilityAnalyzerOrganizationSharingRequest = {
    import EnableReachabilityAnalyzerOrganizationSharingRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.EnableReachabilityAnalyzerOrganizationSharingRequest
      .builder()
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.EnableReachabilityAnalyzerOrganizationSharingRequest.ReadOnly =
    zio.aws.ec2.model.EnableReachabilityAnalyzerOrganizationSharingRequest
      .wrap(buildAwsValue())
}
object EnableReachabilityAnalyzerOrganizationSharingRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.EnableReachabilityAnalyzerOrganizationSharingRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.EnableReachabilityAnalyzerOrganizationSharingRequest =
      zio.aws.ec2.model.EnableReachabilityAnalyzerOrganizationSharingRequest()
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.EnableReachabilityAnalyzerOrganizationSharingRequest
  ) extends zio.aws.ec2.model.EnableReachabilityAnalyzerOrganizationSharingRequest.ReadOnly
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.EnableReachabilityAnalyzerOrganizationSharingRequest
  ): zio.aws.ec2.model.EnableReachabilityAnalyzerOrganizationSharingRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.13-7.21.15.12-sources.jar: zio/aws/ec2/model/EnableReachabilityAnalyzerOrganizationSharingRequest.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class EnableReachabilityAnalyzerOrganizationSharingRequest(
    dryRun: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.EnableReachabilityAnalyzerOrganizationSharingRequest = {
    import EnableReachabilityAnalyzerOrganizationSharingRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.EnableReachabilityAnalyzerOrganizationSharingRequest
      .builder()
      .optionallyWith(dryRun.map(value => value: java.lang.Boolean))(_.dryRun)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.EnableReachabilityAnalyzerOrganizationSharingRequest.ReadOnly =
    zio.aws.ec2.model.EnableReachabilityAnalyzerOrganizationSharingRequest
      .wrap(buildAwsValue())
}
object EnableReachabilityAnalyzerOrganizationSharingRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.EnableReachabilityAnalyzerOrganizationSharingRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.EnableReachabilityAnalyzerOrganizationSharingRequest =
      zio.aws.ec2.model.EnableReachabilityAnalyzerOrganizationSharingRequest(
        dryRun.map(value => value)
      )
    def dryRun: Optional[Boolean]
    def getDryRun: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("dryRun", dryRun)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.EnableReachabilityAnalyzerOrganizationSharingRequest
  ) extends zio.aws.ec2.model.EnableReachabilityAnalyzerOrganizationSharingRequest.ReadOnly {
    override val dryRun: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.dryRun())
      .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.EnableReachabilityAnalyzerOrganizationSharingRequest
  ): zio.aws.ec2.model.EnableReachabilityAnalyzerOrganizationSharingRequest.ReadOnly =
    new Wrapper(impl)
}
